# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import date_pb2  # type: ignore
from google.type import dayofweek_pb2  # type: ignore
from google.type import timeofday_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import report_definition as gaa_report_definition
from google.ads.admanager_v1.types import report_value

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Report",
        "ReportDataTable",
        "ScheduleOptions",
    },
)


class Report(proto.Message):
    r"""The ``Report`` resource.

    Attributes:
        name (str):
            Identifier. The resource name of the report. Report resource
            name have the form:
            ``networks/{network_code}/reports/{report_id}``
        report_id (int):
            Output only. Report ID.
        visibility (google.ads.admanager_v1.types.Report.Visibility):
            Optional. The visibility of a report.
        report_definition (google.ads.admanager_v1.types.ReportDefinition):
            Required. The report definition of the
            report.
        display_name (str):
            Optional. Display name for the report.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant this report was last
            modified.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant this report was
            created.
        locale (str):
            Output only. The locale of this report.
            Locale is set from the user's locale at the time
            of the request. Locale can't be modified.
        schedule_options (google.ads.admanager_v1.types.ScheduleOptions):
            Optional. The schedule options of this
            report.
    """

    class Visibility(proto.Enum):
        r"""The visibility of a report.

        Values:
            HIDDEN (0):
                Default value. Reports with hidden visibility
                won't appear in the Ad Manager UI.
            DRAFT (1):
                Reports with draft visibility will appear in
                the Ad Manager UI only if the user has
                configured the UI to show them.
            SAVED (2):
                Reports with saved visibility will appear in
                the Ad Manager UI by default. Alias for VISIBLE
                and will be replaced in the future.
            VISIBLE (2):
                Reports with this visibility will appear in
                the Ad Manager UI.
        """
        _pb_options = {"allow_alias": True}
        HIDDEN = 0
        DRAFT = 1
        SAVED = 2
        VISIBLE = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    report_id: int = proto.Field(
        proto.INT64,
        number=3,
    )
    visibility: Visibility = proto.Field(
        proto.ENUM,
        number=2,
        enum=Visibility,
    )
    report_definition: gaa_report_definition.ReportDefinition = proto.Field(
        proto.MESSAGE,
        number=4,
        message=gaa_report_definition.ReportDefinition,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=5,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    locale: str = proto.Field(
        proto.STRING,
        number=8,
    )
    schedule_options: "ScheduleOptions" = proto.Field(
        proto.MESSAGE,
        number=9,
        message="ScheduleOptions",
    )


class ReportDataTable(proto.Message):
    r"""A table containing report data including dimension and metric
    values.

    """

    class Row(proto.Message):
        r"""A row of report data.

        Attributes:
            dimension_values (MutableSequence[google.ads.admanager_v1.types.ReportValue]):
                The order of the dimension values is the same
                as the order of the dimensions specified in the
                request.
            metric_value_groups (MutableSequence[google.ads.admanager_v1.types.ReportDataTable.MetricValueGroup]):
                The length of the metric_value_groups field will be equal to
                the length of the date_ranges field in the fetch response.
                The metric_value_groups field is ordered such that each
                index corresponds to the date_range at the same index. For
                example, given date_ranges [x, y], metric_value_groups will
                have a length of two. The first entry in metric_value_groups
                represents the metrics for date x and the second entry in
                metric_value_groups represents the metrics for date y.
        """

        dimension_values: MutableSequence[
            report_value.ReportValue
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=report_value.ReportValue,
        )
        metric_value_groups: MutableSequence[
            "ReportDataTable.MetricValueGroup"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="ReportDataTable.MetricValueGroup",
        )

    class MetricValueGroup(proto.Message):
        r"""Contains all metric values requested for a single date range
        and set of column dimension values (returned in the columns
        field of the response). The order of the metrics in each field
        corresponds to the order of the metrics specified in the
        request.

        Attributes:
            primary_values (MutableSequence[google.ads.admanager_v1.types.ReportValue]):
                Data for the PRIMARY MetricValueType.
            primary_percent_of_total_values (MutableSequence[google.ads.admanager_v1.types.ReportValue]):
                Data for the PRIMARY_PERCENT_OF_TOTAL MetricValueType.
            comparison_values (MutableSequence[google.ads.admanager_v1.types.ReportValue]):
                Data for the COMPARISON MetricValueType.
            comparison_percent_of_total_values (MutableSequence[google.ads.admanager_v1.types.ReportValue]):
                Data for the COMPARISON_PERCENT_OF_TOTAL MetricValueType.
            absolute_change_values (MutableSequence[google.ads.admanager_v1.types.ReportValue]):
                Data for the ABSOLUTE_CHANGE MetricValueType.
            relative_change_values (MutableSequence[google.ads.admanager_v1.types.ReportValue]):
                Data for the RELATIVE_CHANGE MetricValueType.
            flag_values (MutableSequence[bool]):
                If true, the flag's conditions are met. If false, the flag's
                conditions are not met. flag_values has the same length as
                flags and index i of flag_values represents the flag at
                index i of flags.
        """

        primary_values: MutableSequence[report_value.ReportValue] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=report_value.ReportValue,
        )
        primary_percent_of_total_values: MutableSequence[
            report_value.ReportValue
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message=report_value.ReportValue,
        )
        comparison_values: MutableSequence[
            report_value.ReportValue
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=3,
            message=report_value.ReportValue,
        )
        comparison_percent_of_total_values: MutableSequence[
            report_value.ReportValue
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message=report_value.ReportValue,
        )
        absolute_change_values: MutableSequence[
            report_value.ReportValue
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=5,
            message=report_value.ReportValue,
        )
        relative_change_values: MutableSequence[
            report_value.ReportValue
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=6,
            message=report_value.ReportValue,
        )
        flag_values: MutableSequence[bool] = proto.RepeatedField(
            proto.BOOL,
            number=7,
        )


class ScheduleOptions(proto.Message):
    r"""The options for a scheduled report.

    Attributes:
        schedule (google.ads.admanager_v1.types.ScheduleOptions.Schedule):
            Information pertaining to schedule itself.
        delivery_condition (google.ads.admanager_v1.types.ScheduleOptions.DeliveryCondition):
            Option for when to deliver the scheduled
            report.
        flags (MutableSequence[google.ads.admanager_v1.types.ReportDefinition.Flag]):
            Optional. The flags evaluated when
            ReportDeliveryOption.WHEN_FLAG_PRESENT is specified.
    """

    class DeliveryCondition(proto.Enum):
        r"""Condition for when to email the scheduled report.

        Values:
            NEVER (0):
                Never deliver report.
            ALWAYS (1):
                Always deliver report.
            WHEN_FLAG_CONDITIONS_MET (2):
                Deliver report when flag's conditions are
                met.
        """
        NEVER = 0
        ALWAYS = 1
        WHEN_FLAG_CONDITIONS_MET = 2

    class Schedule(proto.Message):
        r"""The schedule for the report

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            weekly_schedule (google.ads.admanager_v1.types.ScheduleOptions.Schedule.WeeklySchedule):
                Days of week to schedule report run.

                This field is a member of `oneof`_ ``frequency_schedule``.
            monthly_schedule (google.ads.admanager_v1.types.ScheduleOptions.Schedule.MonthlySchedule):
                Days of month to schedule report run.

                This field is a member of `oneof`_ ``frequency_schedule``.
            start_date (google.type.date_pb2.Date):
                Date for the first run of the report.
            end_date (google.type.date_pb2.Date):
                Date for the final run of the report.
            frequency (google.ads.admanager_v1.types.ScheduleOptions.Schedule.Frequency):
                Frequency to run report.
            start_time (google.type.timeofday_pb2.TimeOfDay):
                Indicates start time for schedule to run Will use the
                time_zone from ``ReportDefinition``. Defaults to the
                publisher's time zone if not specified.

                For HOURLY, TWO_TIMES_DAILY, THREE_TIMES_DAILY, or
                FOUR_TIMES_DAILY, this will be the time of day that the
                first report will run on the first day. For example, if the
                start time is 2:00 PM, and the frequency is
                THREE_TIMES_DAILY, the first day will have reports scheduled
                at 2:00 PM, 10:00 PM. Each subsequent day will have reports
                scheduled at 6:00 AM, 2:00 PM, 10:00 PM.
        """

        class Frequency(proto.Enum):
            r"""Frequency to run report.

            Values:
                FREQUENCY_UNSPECIFIED (0):
                    No Frequency specified.
                HOURLY (1):
                    Schedule report to run every hour.
                TWO_TIMES_DAILY (2):
                    Schedule report to run twice a day (every 12
                    hours).
                THREE_TIMES_DAILY (3):
                    Schedule report to run three times a day
                    (every 8 hours).
                FOUR_TIMES_DAILY (4):
                    Schedule report to run four times a day
                    (every 6 hours).
                DAILY (5):
                    Schedule report to run on a daily basis.
                WEEKLY (6):
                    Schedule report to run on a weekly basis.
                MONTHLY (7):
                    Schedule report to run on a monthly basis.
            """
            FREQUENCY_UNSPECIFIED = 0
            HOURLY = 1
            TWO_TIMES_DAILY = 2
            THREE_TIMES_DAILY = 3
            FOUR_TIMES_DAILY = 4
            DAILY = 5
            WEEKLY = 6
            MONTHLY = 7

        class WeeklySchedule(proto.Message):
            r"""Days of week to schedule report run.

            Attributes:
                weekly_scheduled_days (MutableSequence[google.type.dayofweek_pb2.DayOfWeek]):
                    Specifies days of the week on which to run
                    report.
            """

            weekly_scheduled_days: MutableSequence[
                dayofweek_pb2.DayOfWeek
            ] = proto.RepeatedField(
                proto.ENUM,
                number=1,
                enum=dayofweek_pb2.DayOfWeek,
            )

        class MonthlySchedule(proto.Message):
            r"""Days of Month to schedule report run.

            Attributes:
                monthly_scheduled_days (MutableSequence[int]):
                    Specifies days of the month to run report.
                    Range is from 1-31. Will ignore days that are
                    not valid for the given month.
            """

            monthly_scheduled_days: MutableSequence[int] = proto.RepeatedField(
                proto.INT32,
                number=1,
            )

        weekly_schedule: "ScheduleOptions.Schedule.WeeklySchedule" = proto.Field(
            proto.MESSAGE,
            number=6,
            oneof="frequency_schedule",
            message="ScheduleOptions.Schedule.WeeklySchedule",
        )
        monthly_schedule: "ScheduleOptions.Schedule.MonthlySchedule" = proto.Field(
            proto.MESSAGE,
            number=7,
            oneof="frequency_schedule",
            message="ScheduleOptions.Schedule.MonthlySchedule",
        )
        start_date: date_pb2.Date = proto.Field(
            proto.MESSAGE,
            number=1,
            message=date_pb2.Date,
        )
        end_date: date_pb2.Date = proto.Field(
            proto.MESSAGE,
            number=2,
            message=date_pb2.Date,
        )
        frequency: "ScheduleOptions.Schedule.Frequency" = proto.Field(
            proto.ENUM,
            number=3,
            enum="ScheduleOptions.Schedule.Frequency",
        )
        start_time: timeofday_pb2.TimeOfDay = proto.Field(
            proto.MESSAGE,
            number=4,
            message=timeofday_pb2.TimeOfDay,
        )

    schedule: Schedule = proto.Field(
        proto.MESSAGE,
        number=1,
        message=Schedule,
    )
    delivery_condition: DeliveryCondition = proto.Field(
        proto.ENUM,
        number=2,
        enum=DeliveryCondition,
    )
    flags: MutableSequence[
        gaa_report_definition.ReportDefinition.Flag
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=gaa_report_definition.ReportDefinition.Flag,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Iterator,
    Optional,
    Sequence,
    Tuple,
    Union,
)

from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import retry_async as retries_async

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault, None]
    OptionalAsyncRetry = Union[
        retries_async.AsyncRetry, gapic_v1.method._MethodDefault, None
    ]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object, None]  # type: ignore
    OptionalAsyncRetry = Union[retries_async.AsyncRetry, object, None]  # type: ignore

from google.ads.admanager_v1.types import (
    ad_review_center_ad_messages,
    ad_review_center_ad_service,
)


class SearchAdReviewCenterAdsPager:
    """A pager for iterating through ``search_ad_review_center_ads`` requests.

    This class thinly wraps an initial
    :class:`google.ads.admanager_v1.types.SearchAdReviewCenterAdsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``ad_review_center_ads`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``SearchAdReviewCenterAds`` requests and continue to iterate
    through the ``ad_review_center_ads`` field on the
    corresponding responses.

    All the usual :class:`google.ads.admanager_v1.types.SearchAdReviewCenterAdsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., ad_review_center_ad_service.SearchAdReviewCenterAdsResponse
        ],
        request: ad_review_center_ad_service.SearchAdReviewCenterAdsRequest,
        response: ad_review_center_ad_service.SearchAdReviewCenterAdsResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.ads.admanager_v1.types.SearchAdReviewCenterAdsRequest):
                The initial request object.
            response (google.ads.admanager_v1.types.SearchAdReviewCenterAdsResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.
        """
        self._method = method
        self._request = ad_review_center_ad_service.SearchAdReviewCenterAdsRequest(
            request
        )
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(
        self,
    ) -> Iterator[ad_review_center_ad_service.SearchAdReviewCenterAdsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[ad_review_center_ad_messages.AdReviewCenterAd]:
        for page in self.pages:
            yield from page.ad_review_center_ads

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import ad_unit_messages

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "GetAdUnitRequest",
        "ListAdUnitsRequest",
        "ListAdUnitsResponse",
        "CreateAdUnitRequest",
        "UpdateAdUnitRequest",
        "BatchCreateAdUnitsRequest",
        "BatchCreateAdUnitsResponse",
        "BatchUpdateAdUnitsRequest",
        "BatchUpdateAdUnitsResponse",
        "ListAdUnitSizesRequest",
        "ListAdUnitSizesResponse",
        "BatchActivateAdUnitsRequest",
        "BatchActivateAdUnitsResponse",
        "BatchDeactivateAdUnitsRequest",
        "BatchDeactivateAdUnitsResponse",
        "BatchArchiveAdUnitsRequest",
        "BatchArchiveAdUnitsResponse",
    },
)


class GetAdUnitRequest(proto.Message):
    r"""Request object for GetAdUnit method.

    Attributes:
        name (str):
            Required. The resource name of the AdUnit. Format:
            ``networks/{network_code}/adUnits/{ad_unit_id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListAdUnitsRequest(proto.Message):
    r"""Request object for ListAdUnits method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of AdUnits.
            Format: ``networks/{network_code}``
        page_size (int):
            Optional. The maximum number of AdUnits to
            return. The service may return fewer than this
            value. If unspecified, at most 50 ad units will
            be returned. The maximum value is 1000; values
            greater than 1000 will be coerced to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListAdUnits`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListAdUnits`` must match the call that provided the page
            token.
        filter (str):
            Optional. Expression to filter the response.
            See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters
        order_by (str):
            Optional. Expression to specify sorting
            order. See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters#order
        skip (int):
            Optional. Number of individual resources to
            skip while paginating.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )
    skip: int = proto.Field(
        proto.INT32,
        number=6,
    )


class ListAdUnitsResponse(proto.Message):
    r"""Response object for ListAdUnitsRequest containing matching
    AdUnit resources.

    Attributes:
        ad_units (MutableSequence[google.ads.admanager_v1.types.AdUnit]):
            The AdUnit from the specified network.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
        total_size (int):
            Total number of AdUnits. If a filter was included in the
            request, this reflects the total number after the filtering
            is applied.

            ``total_size`` won't be calculated in the response unless it
            has been included in a response field mask. The response
            field mask can be provided to the method by using the URL
            parameter ``$fields`` or ``fields``, or by using the
            HTTP/gRPC header ``X-Goog-FieldMask``.

            For more information, see
            https://developers.google.com/ad-manager/api/beta/field-masks
    """

    @property
    def raw_page(self):
        return self

    ad_units: MutableSequence[ad_unit_messages.AdUnit] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_unit_messages.AdUnit,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


class CreateAdUnitRequest(proto.Message):
    r"""Request object for ``CreateAdUnit`` method.

    Attributes:
        parent (str):
            Required. The parent resource where this ``AdUnit`` will be
            created. Format: ``networks/{network_code}``
        ad_unit (google.ads.admanager_v1.types.AdUnit):
            Required. The ``AdUnit`` to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ad_unit: ad_unit_messages.AdUnit = proto.Field(
        proto.MESSAGE,
        number=2,
        message=ad_unit_messages.AdUnit,
    )


class UpdateAdUnitRequest(proto.Message):
    r"""Request object for ``UpdateAdUnit`` method.

    Attributes:
        ad_unit (google.ads.admanager_v1.types.AdUnit):
            Required. The ``AdUnit`` to update.

            The ``AdUnit``'s name is used to identify the ``AdUnit`` to
            update. Format:
            ``networks/{network_code}/adUnits/{ad_unit_id}``
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update.
    """

    ad_unit: ad_unit_messages.AdUnit = proto.Field(
        proto.MESSAGE,
        number=1,
        message=ad_unit_messages.AdUnit,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class BatchCreateAdUnitsRequest(proto.Message):
    r"""Request object for ``BatchCreateAdUnits`` method.

    Attributes:
        parent (str):
            Required. The parent resource where ``AdUnits`` will be
            created. Format: ``networks/{network_code}`` The parent
            field in the CreateAdUnitRequest must match this field.
        requests (MutableSequence[google.ads.admanager_v1.types.CreateAdUnitRequest]):
            Required. The ``AdUnit`` objects to create. A maximum of 100
            objects can be created in a batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["CreateAdUnitRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="CreateAdUnitRequest",
    )


class BatchCreateAdUnitsResponse(proto.Message):
    r"""Response object for ``BatchCreateAdUnits`` method.

    Attributes:
        ad_units (MutableSequence[google.ads.admanager_v1.types.AdUnit]):
            The ``AdUnit`` objects created.
    """

    ad_units: MutableSequence[ad_unit_messages.AdUnit] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_unit_messages.AdUnit,
    )


class BatchUpdateAdUnitsRequest(proto.Message):
    r"""Request object for ``BatchUpdateAdUnits`` method.

    Attributes:
        parent (str):
            Required. The parent resource where ``AdUnits`` will be
            updated. Format: ``networks/{network_code}`` The parent
            field in the UpdateAdUnitRequest must match this field.
        requests (MutableSequence[google.ads.admanager_v1.types.UpdateAdUnitRequest]):
            Required. The ``AdUnit`` objects to update. A maximum of 100
            objects can be updated in a batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["UpdateAdUnitRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="UpdateAdUnitRequest",
    )


class BatchUpdateAdUnitsResponse(proto.Message):
    r"""Response object for ``BatchUpdateAdUnits`` method.

    Attributes:
        ad_units (MutableSequence[google.ads.admanager_v1.types.AdUnit]):
            The ``AdUnit`` objects updated.
    """

    ad_units: MutableSequence[ad_unit_messages.AdUnit] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_unit_messages.AdUnit,
    )


class ListAdUnitSizesRequest(proto.Message):
    r"""Request object for ListAdUnitSizes method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of
            AdUnitSizes. Format: ``networks/{network_code}``
        page_size (int):
            Optional. The maximum number of AdUnitSizes
            to return. The service may return fewer than
            this value. If unspecified, at most 50 ad unit
            sizes will be returned. The maximum value is
            1000; values greater than 1000 will be coerced
            to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListAdUnitSizes`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListAdUnitSizes`` must match the call that provided the
            page token.
        filter (str):
            Optional. Expression to filter the response.
            See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters
        order_by (str):
            Optional. Expression to specify sorting
            order. See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters#order
        skip (int):
            Optional. Number of individual resources to
            skip while paginating.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )
    skip: int = proto.Field(
        proto.INT32,
        number=6,
    )


class ListAdUnitSizesResponse(proto.Message):
    r"""Response object for ListAdUnitSizesRequest containing
    matching AdUnitSizes.

    Attributes:
        ad_unit_sizes (MutableSequence[google.ads.admanager_v1.types.AdUnitSize]):
            The AdUnitSizes from the specified network.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
        total_size (int):
            Total number of AdUnitSizes. If a filter was included in the
            request, this reflects the total number after the filtering
            is applied.

            ``total_size`` won't be calculated in the response unless it
            has been included in a response field mask. The response
            field mask can be provided to the method by using the URL
            parameter ``$fields`` or ``fields``, or by using the
            HTTP/gRPC header ``X-Goog-FieldMask``.

            For more information, see
            https://developers.google.com/ad-manager/api/beta/field-masks
    """

    @property
    def raw_page(self):
        return self

    ad_unit_sizes: MutableSequence[ad_unit_messages.AdUnitSize] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_unit_messages.AdUnitSize,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


class BatchActivateAdUnitsRequest(proto.Message):
    r"""Request object for ``BatchActivateAdUnits`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The resource names of the ``AdUnit``\ s to
            activate. Format:
            ``networks/{network_code}/adUnits/{ad_unit_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class BatchActivateAdUnitsResponse(proto.Message):
    r"""Response object for ``BatchActivateAdUnits`` method."""


class BatchDeactivateAdUnitsRequest(proto.Message):
    r"""Request object for ``BatchDeactivateAdUnits`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The resource names of the ``AdUnit``\ s to
            deactivate. Format:
            ``networks/{network_code}/adUnits/{ad_unit_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class BatchDeactivateAdUnitsResponse(proto.Message):
    r"""Response object for ``BatchDeactivateAdUnits`` method."""


class BatchArchiveAdUnitsRequest(proto.Message):
    r"""Request object for ``BatchArchiveAdUnits`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The resource names of the ``AdUnit``\ s to
            archive. Format:
            ``networks/{network_code}/adUnits/{ad_unit_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class BatchArchiveAdUnitsResponse(proto.Message):
    r"""Response object for ``BatchArchiveAdUnits`` method."""


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import taxonomy_type_enum

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "TaxonomyCategory",
    },
)


class TaxonomyCategory(proto.Message):
    r"""The ``TaxonomyCategory`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``TaxonomyCategory``.
            Format:
            ``networks/{network_code}/taxonomyCategories/{taxonomy_category_id}``
        taxonomy_category_id (int):
            Output only. ``TaxonomyCategory`` ID.

            This field is a member of `oneof`_ ``_taxonomy_category_id``.
        display_name (str):
            Output only. Display name of the ``TaxonomyCategory``.

            This field is a member of `oneof`_ ``_display_name``.
        grouping_only (bool):
            Output only. Whether this ``TaxonomyCategory`` only serves
            to group its children.

            This field is a member of `oneof`_ ``_grouping_only``.
        parent_taxonomy_category_id (int):
            Output only. The ID of the parent category this
            ``TaxonomyCategory`` descends from.

            This field is a member of `oneof`_ ``_parent_taxonomy_category_id``.
        taxonomy_type (google.ads.admanager_v1.types.TaxonomyTypeEnum.TaxonomyType):
            Output only. The taxonomy that this ``TaxonomyCategory``
            belongs to.

            This field is a member of `oneof`_ ``_taxonomy_type``.
        ancestor_names (MutableSequence[str]):
            Output only. The list of names of the ancestors of this
            ``TaxonomyCategory``.
        ancestor_taxonomy_category_ids (MutableSequence[int]):
            Output only. The list of IDs of the ancestors of this
            ``TaxonomyCategory``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    taxonomy_category_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    grouping_only: bool = proto.Field(
        proto.BOOL,
        number=5,
        optional=True,
    )
    parent_taxonomy_category_id: int = proto.Field(
        proto.INT64,
        number=6,
        optional=True,
    )
    taxonomy_type: taxonomy_type_enum.TaxonomyTypeEnum.TaxonomyType = proto.Field(
        proto.ENUM,
        number=9,
        optional=True,
        enum=taxonomy_type_enum.TaxonomyTypeEnum.TaxonomyType,
    )
    ancestor_names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    ancestor_taxonomy_category_ids: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=8,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import placement_messages

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "GetPlacementRequest",
        "ListPlacementsRequest",
        "ListPlacementsResponse",
        "CreatePlacementRequest",
        "BatchCreatePlacementsRequest",
        "BatchCreatePlacementsResponse",
        "UpdatePlacementRequest",
        "BatchUpdatePlacementsRequest",
        "BatchUpdatePlacementsResponse",
        "BatchActivatePlacementsRequest",
        "BatchActivatePlacementsResponse",
        "BatchDeactivatePlacementsRequest",
        "BatchDeactivatePlacementsResponse",
        "BatchArchivePlacementsRequest",
        "BatchArchivePlacementsResponse",
    },
)


class GetPlacementRequest(proto.Message):
    r"""Request object for ``GetPlacement`` method.

    Attributes:
        name (str):
            Required. The resource name of the Placement. Format:
            ``networks/{network_code}/placements/{placement_id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListPlacementsRequest(proto.Message):
    r"""Request object for ``ListPlacements`` method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of
            Placements. Format: ``networks/{network_code}``
        page_size (int):
            Optional. The maximum number of ``Placements`` to return.
            The service may return fewer than this value. If
            unspecified, at most 50 ``Placements`` will be returned. The
            maximum value is 1000; values greater than 1000 will be
            coerced to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListPlacements`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListPlacements`` must match the call that provided the
            page token.
        filter (str):
            Optional. Expression to filter the response.
            See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters
        order_by (str):
            Optional. Expression to specify sorting
            order. See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters#order
        skip (int):
            Optional. Number of individual resources to
            skip while paginating.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )
    skip: int = proto.Field(
        proto.INT32,
        number=6,
    )


class ListPlacementsResponse(proto.Message):
    r"""Response object for ``ListPlacementsRequest`` containing matching
    ``Placement`` objects.

    Attributes:
        placements (MutableSequence[google.ads.admanager_v1.types.Placement]):
            The ``Placement`` objects from the specified network.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
        total_size (int):
            Total number of ``Placement`` objects. If a filter was
            included in the request, this reflects the total number
            after the filtering is applied.

            ``total_size`` won't be calculated in the response unless it
            has been included in a response field mask. The response
            field mask can be provided to the method by using the URL
            parameter ``$fields`` or ``fields``, or by using the
            HTTP/gRPC header ``X-Goog-FieldMask``.

            For more information, see
            https://developers.google.com/ad-manager/api/beta/field-masks
    """

    @property
    def raw_page(self):
        return self

    placements: MutableSequence[placement_messages.Placement] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=placement_messages.Placement,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


class CreatePlacementRequest(proto.Message):
    r"""Request object for ``CreatePlacement`` method.

    Attributes:
        parent (str):
            Required. The parent resource where this ``Placement`` will
            be created. Format: ``networks/{network_code}``
        placement (google.ads.admanager_v1.types.Placement):
            Required. The ``Placement`` to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    placement: placement_messages.Placement = proto.Field(
        proto.MESSAGE,
        number=2,
        message=placement_messages.Placement,
    )


class BatchCreatePlacementsRequest(proto.Message):
    r"""Request object for ``BatchCreatePlacements`` method.

    Attributes:
        parent (str):
            Required. The parent resource where the ``Placement``\ s
            will be created. Format: ``networks/{network_code}`` The
            parent field in the CreatePlacementRequest messages match
            this field.
        requests (MutableSequence[google.ads.admanager_v1.types.CreatePlacementRequest]):
            Required. The ``Placement`` objects to create. A maximum of
            100 objects can be created in a batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["CreatePlacementRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="CreatePlacementRequest",
    )


class BatchCreatePlacementsResponse(proto.Message):
    r"""Response object for ``BatchCreatePlacements`` method.

    Attributes:
        placements (MutableSequence[google.ads.admanager_v1.types.Placement]):
            The ``Placement`` objects created.
    """

    placements: MutableSequence[placement_messages.Placement] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=placement_messages.Placement,
    )


class UpdatePlacementRequest(proto.Message):
    r"""Request object for ``UpdatePlacement`` method.

    Attributes:
        placement (google.ads.admanager_v1.types.Placement):
            Required. The ``Placement`` to update.

            The ``Placement``'s name is used to identify the
            ``Placement`` to update. Format:
            ``networks/{network_code}/placements/{placement_id}``
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update.
    """

    placement: placement_messages.Placement = proto.Field(
        proto.MESSAGE,
        number=1,
        message=placement_messages.Placement,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class BatchUpdatePlacementsRequest(proto.Message):
    r"""Request object for ``BatchUpdatePlacements`` method.

    Attributes:
        parent (str):
            Required. The parent resource where ``Placements`` will be
            updated. Format: ``networks/{network_code}`` The parent
            field in the UpdatePlacementsRequest must match this field.
        requests (MutableSequence[google.ads.admanager_v1.types.UpdatePlacementRequest]):
            Required. The ``Placement`` objects to update. A maximum of
            100 objects can be updated in a batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["UpdatePlacementRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="UpdatePlacementRequest",
    )


class BatchUpdatePlacementsResponse(proto.Message):
    r"""Response object for ``BatchUpdatePlacements`` method.

    Attributes:
        placements (MutableSequence[google.ads.admanager_v1.types.Placement]):
            The ``Placement`` objects updated.
    """

    placements: MutableSequence[placement_messages.Placement] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=placement_messages.Placement,
    )


class BatchActivatePlacementsRequest(proto.Message):
    r"""Request message for ``BatchActivatePlacements`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The names of the ``Placement`` objects to
            activate. Format:
            ``networks/{network_code}/placements/{placement_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class BatchActivatePlacementsResponse(proto.Message):
    r"""Response object for ``BatchActivatePlacements`` method."""


class BatchDeactivatePlacementsRequest(proto.Message):
    r"""Request message for ``BatchDeactivatePlacements`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The names of the ``Placement`` objects to
            deactivate. Format:
            ``networks/{network_code}/placements/{placement_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class BatchDeactivatePlacementsResponse(proto.Message):
    r"""Response object for ``BatchDeactivatePlacements`` method."""


class BatchArchivePlacementsRequest(proto.Message):
    r"""Request message for ``BatchArchivePlacements`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The names of the ``Placement`` objects to archive.
            Format:
            ``networks/{network_code}/placements/{placement_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class BatchArchivePlacementsResponse(proto.Message):
    r"""Response object for ``BatchArchivePlacements`` method."""


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CreativeTemplateTypeEnum",
        "CreativeTemplateStatusEnum",
    },
)


class CreativeTemplateTypeEnum(proto.Message):
    r"""Wrapper message for
    [CreativeTemplateType][google.ads.admanager.v1.CreativeTemplateTypeEnum.CreativeTemplateType]

    """

    class CreativeTemplateType(proto.Enum):
        r"""Describes type of the creative template.

        Values:
            CREATIVE_TEMPLATE_TYPE_UNSPECIFIED (0):
                Default value. This value is unused.
            STANDARD (1):
                Creative templates that are included in Ad
                Manager by default.
            CUSTOM (2):
                Creative templates created by an
                administrator or other user in the network.
        """
        CREATIVE_TEMPLATE_TYPE_UNSPECIFIED = 0
        STANDARD = 1
        CUSTOM = 2


class CreativeTemplateStatusEnum(proto.Message):
    r"""Wrapper message for
    [CreativeTemplateStatus][google.ads.admanager.v1.CreativeTemplateStatusEnum.CreativeTemplateStatus]

    """

    class CreativeTemplateStatus(proto.Enum):
        r"""Describes status of the creative template

        Values:
            CREATIVE_TEMPLATE_STATUS_UNSPECIFIED (0):
                Default value. This value is unused.
            ACTIVE (1):
                The CreativeTemplate is active
            DELETED (2):
                The CreativeTemplate is deleted. Creatives
                created from this CreativeTemplate can no longer
                serve.
            INACTIVE (3):
                The CreativeTemplate is inactive. Users
                cannot create new creatives from this template,
                but existing ones can be edited and continue to
                serve
        """
        CREATIVE_TEMPLATE_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        DELETED = 2
        INACTIVE = 3


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import (
    creative_template_enums,
    creative_template_variable_url_type_enum,
)

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CreativeTemplate",
        "CreativeTemplateVariable",
    },
)


class CreativeTemplate(proto.Message):
    r"""A template that can be used to create a [TemplateCreative][].

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the creative template.
            Format:
            ``networks/{network_code}/creativeTemplates/{creative_template_id}``
        display_name (str):
            Required. The display name of the creative
            template. This has a maximum length of 255
            characters.

            This field is a member of `oneof`_ ``_display_name``.
        description (str):
            Optional. The description of the creative
            template.

            This field is a member of `oneof`_ ``_description``.
        snippet (str):
            Required. The code snippet of the creative
            template, with placeholders for the associated
            variables.

            This field is a member of `oneof`_ ``_snippet``.
        status (google.ads.admanager_v1.types.CreativeTemplateStatusEnum.CreativeTemplateStatus):
            Output only. The status of the creative
            template. This attribute is assigned by Google.

            This field is a member of `oneof`_ ``_status``.
        type_ (google.ads.admanager_v1.types.CreativeTemplateTypeEnum.CreativeTemplateType):
            Optional. The type of the creative template. Users can only
            create or update ``CreativeTemplateType.CUSTOM`` templates.

            This field is a member of `oneof`_ ``_type``.
        interstitial (bool):
            Optional. ``True`` if this creative template produces
            out-of-page creatives. Creative templates with this setting
            enabled must include the viewed impression macro.

            This field is a member of `oneof`_ ``_interstitial``.
        native_eligible (bool):
            Optional. ``True`` if this creative template produces
            native-eligible creatives.

            This field is a member of `oneof`_ ``_native_eligible``.
        native_video_eligible (bool):
            Optional. ``True`` if this creative template produces native
            video-eligible creatives.

            This field is a member of `oneof`_ ``_native_video_eligible``.
        safe_frame_compatible (bool):
            Optional. Whether the Creative produced is compatible for
            SafeFrame rendering. This attribute defaults to ``True``.

            This field is a member of `oneof`_ ``_safe_frame_compatible``.
        variables (MutableSequence[google.ads.admanager_v1.types.CreativeTemplateVariable]):
            Required. The list of creative template
            variables.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    snippet: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    status: creative_template_enums.CreativeTemplateStatusEnum.CreativeTemplateStatus = proto.Field(
        proto.ENUM,
        number=6,
        optional=True,
        enum=creative_template_enums.CreativeTemplateStatusEnum.CreativeTemplateStatus,
    )
    type_: creative_template_enums.CreativeTemplateTypeEnum.CreativeTemplateType = (
        proto.Field(
            proto.ENUM,
            number=7,
            optional=True,
            enum=creative_template_enums.CreativeTemplateTypeEnum.CreativeTemplateType,
        )
    )
    interstitial: bool = proto.Field(
        proto.BOOL,
        number=8,
        optional=True,
    )
    native_eligible: bool = proto.Field(
        proto.BOOL,
        number=9,
        optional=True,
    )
    native_video_eligible: bool = proto.Field(
        proto.BOOL,
        number=10,
        optional=True,
    )
    safe_frame_compatible: bool = proto.Field(
        proto.BOOL,
        number=12,
        optional=True,
    )
    variables: MutableSequence["CreativeTemplateVariable"] = proto.RepeatedField(
        proto.MESSAGE,
        number=14,
        message="CreativeTemplateVariable",
    )


class CreativeTemplateVariable(proto.Message):
    r"""Represents a variable defined in a creative template.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        asset_variable (google.ads.admanager_v1.types.CreativeTemplateVariable.AssetCreativeTemplateVariable):
            Optional. Represents a file asset variable
            defined in a creative template.

            This field is a member of `oneof`_ ``SubType``.
        list_string_variable (google.ads.admanager_v1.types.CreativeTemplateVariable.ListStringCreativeTemplateVariable):
            Optional. Represents a list variable defined
            in a creative template.

            This field is a member of `oneof`_ ``SubType``.
        long_variable (google.ads.admanager_v1.types.CreativeTemplateVariable.LongCreativeTemplateVariable):
            Optional. Represents a long variable defined
            in a creative template.

            This field is a member of `oneof`_ ``SubType``.
        string_variable (google.ads.admanager_v1.types.CreativeTemplateVariable.StringCreativeTemplateVariable):
            Optional. Represents a string variable
            defined in a creative template.

            This field is a member of `oneof`_ ``SubType``.
        url_variable (google.ads.admanager_v1.types.CreativeTemplateVariable.UrlCreativeTemplateVariable):
            Optional. Represents a url variable defined
            in a creative template.

            This field is a member of `oneof`_ ``SubType``.
        label (str):
            Required. Label that is displayed to users
            when creating from the creative template. This
            has a maximum length of 127 characters.

            This field is a member of `oneof`_ ``_label``.
        unique_display_name (str):
            Output only. Unique name used to identify the
            variable. This attribute is assigned by Google
            when a creative template variable is created.

            This field is a member of `oneof`_ ``_unique_display_name``.
        description (str):
            Required. A descriptive help text that is
            displayed to users along with the label. This
            attribute has a maximum length of 255
            characters.

            This field is a member of `oneof`_ ``_description``.
        required (bool):
            Optional. ``True`` if this variable is required to be filled
            in by users when creating a creative from the creative
            template.

            This field is a member of `oneof`_ ``_required``.
    """

    class AssetCreativeTemplateVariable(proto.Message):
        r"""Represents a file asset variable defined in a creative template.

        Use [AssetCreativeTemplateVariableValue][] to specify the value for
        this variable when creating a [TemplateCreative][] from a
        [CreativeTemplate][google.ads.admanager.v1.CreativeTemplate].

        Attributes:
            mime_types (MutableSequence[google.ads.admanager_v1.types.CreativeTemplateVariable.AssetCreativeTemplateVariable.MimeType]):
                Optional. The set of allowed MIME types. If
                unspecified, all MIME types are allowed.
        """

        class MimeType(proto.Enum):
            r"""Different MIME types that the asset variable supports.

            Values:
                MIME_TYPE_UNSPECIFIED (0):
                    Default value. This value is unused.
                JPG (1):
                    The ``image/jpeg`` MIME type.
                PNG (2):
                    The ``image/png`` MIME type.
                GIF (3):
                    The ``image/gif`` MIME type.
            """
            MIME_TYPE_UNSPECIFIED = 0
            JPG = 1
            PNG = 2
            GIF = 3

        mime_types: MutableSequence[
            "CreativeTemplateVariable.AssetCreativeTemplateVariable.MimeType"
        ] = proto.RepeatedField(
            proto.ENUM,
            number=1,
            enum="CreativeTemplateVariable.AssetCreativeTemplateVariable.MimeType",
        )

    class ListStringCreativeTemplateVariable(proto.Message):
        r"""Represents a list variable defined in a creative template. This is
        similar to
        [StringCreativeTemplateVariable][google.ads.admanager.v1.CreativeTemplateVariable.StringCreativeTemplateVariable],
        except that there are possible choices to choose from.

        Use [StringCreativeTemplateVariableValue][] to specify the value for
        this variable when creating a [TemplateCreative][] from a
        [CreativeTemplate][google.ads.admanager.v1.CreativeTemplate].


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            default_value (str):
                Optional. Default value to be filled in when
                creating creatives from the creative template.

                This field is a member of `oneof`_ ``_default_value``.
            sample_value (str):
                Optional. Sample value that is used when
                previewing the template in the UI.

                This field is a member of `oneof`_ ``_sample_value``.
            choices (MutableSequence[google.ads.admanager_v1.types.CreativeTemplateVariable.ListStringCreativeTemplateVariable.VariableChoice]):
                Optional. The selectable values that the user
                can choose from.
            allow_other_choice (bool):
                Optional. ``True`` if a user can specify an 'other' value.
                For example, if a variable called backgroundColor is defined
                as a list with values: red, green, blue, this boolean can be
                set to allow a user to enter a value not on the list such as
                purple.

                This field is a member of `oneof`_ ``_allow_other_choice``.
        """

        class VariableChoice(proto.Message):
            r"""Stores variable choices selectable by users.

            .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

            Attributes:
                label (str):
                    Required. A label is displayed to users when creating a
                    [TemplateCreative][]. This attribute is intended to be more
                    descriptive than value. This attribute has a maximum length
                    of 255 characters.

                    This field is a member of `oneof`_ ``_label``.
                value (str):
                    Required. When creating a [TemplateCreative][], the value in
                    [StringCreativeTemplateVariableValue][] should match this
                    value, if you intend to select this value. This attribute
                    has a maximum length of 255 characters.

                    This field is a member of `oneof`_ ``_value``.
            """

            label: str = proto.Field(
                proto.STRING,
                number=1,
                optional=True,
            )
            value: str = proto.Field(
                proto.STRING,
                number=2,
                optional=True,
            )

        default_value: str = proto.Field(
            proto.STRING,
            number=1,
            optional=True,
        )
        sample_value: str = proto.Field(
            proto.STRING,
            number=2,
            optional=True,
        )
        choices: MutableSequence[
            "CreativeTemplateVariable.ListStringCreativeTemplateVariable.VariableChoice"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=3,
            message="CreativeTemplateVariable.ListStringCreativeTemplateVariable.VariableChoice",
        )
        allow_other_choice: bool = proto.Field(
            proto.BOOL,
            number=4,
            optional=True,
        )

    class LongCreativeTemplateVariable(proto.Message):
        r"""Represents a long variable defined in a creative template.

        Use [LongCreativeTemplateVariableValue][] to specify the value for
        this variable when creating [TemplateCreative][] from a
        [CreativeTemplate][google.ads.admanager.v1.CreativeTemplate].


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            default_value (int):
                Optional. Default value to be filled in when
                creating creatives from the creative template.

                This field is a member of `oneof`_ ``_default_value``.
            sample_value (int):
                Optional. Sample value that is used when
                previewing the template in the UI.

                This field is a member of `oneof`_ ``_sample_value``.
        """

        default_value: int = proto.Field(
            proto.INT64,
            number=1,
            optional=True,
        )
        sample_value: int = proto.Field(
            proto.INT64,
            number=2,
            optional=True,
        )

    class StringCreativeTemplateVariable(proto.Message):
        r"""Represents a string variable defined in a creative template.

        Use [StringCreativeTemplateVariableValue][] to specify the value for
        this variable when creating [TemplateCreative][] from a
        [CreativeTemplate][google.ads.admanager.v1.CreativeTemplate].


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            default_value (str):
                Optional. Default value to be filled in when
                creating creatives from the creative template.

                This field is a member of `oneof`_ ``_default_value``.
            sample_value (str):
                Optional. Sample value that is used when
                previewing the template in the UI.

                This field is a member of `oneof`_ ``_sample_value``.
        """

        default_value: str = proto.Field(
            proto.STRING,
            number=1,
            optional=True,
        )
        sample_value: str = proto.Field(
            proto.STRING,
            number=2,
            optional=True,
        )

    class UrlCreativeTemplateVariable(proto.Message):
        r"""Represents a url variable defined in a creative template.

        Use [UrlCreativeTemplateVariableValue][] to specify the value for
        this variable when creating a [TemplateCreative][] from a
        [CreativeTemplate][google.ads.admanager.v1.CreativeTemplate].


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            default_value (str):
                Optional. Default value to be filled in when
                creating creatives from the creative template.

                This field is a member of `oneof`_ ``_default_value``.
            sample_value (str):
                Optional. Sample value that is used when
                previewing the template in the UI.

                This field is a member of `oneof`_ ``_sample_value``.
            url_type (google.ads.admanager_v1.types.CreativeTemplateVariableUrlTypeEnum.CreativeTemplateVariableUrlType):
                Optional. The type of URL that this variable
                represents. Different types of URLs may be
                handled differently at rendering time.

                This field is a member of `oneof`_ ``_url_type``.
        """

        default_value: str = proto.Field(
            proto.STRING,
            number=1,
            optional=True,
        )
        sample_value: str = proto.Field(
            proto.STRING,
            number=2,
            optional=True,
        )
        url_type: creative_template_variable_url_type_enum.CreativeTemplateVariableUrlTypeEnum.CreativeTemplateVariableUrlType = proto.Field(
            proto.ENUM,
            number=4,
            optional=True,
            enum=creative_template_variable_url_type_enum.CreativeTemplateVariableUrlTypeEnum.CreativeTemplateVariableUrlType,
        )

    asset_variable: AssetCreativeTemplateVariable = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="SubType",
        message=AssetCreativeTemplateVariable,
    )
    list_string_variable: ListStringCreativeTemplateVariable = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="SubType",
        message=ListStringCreativeTemplateVariable,
    )
    long_variable: LongCreativeTemplateVariable = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="SubType",
        message=LongCreativeTemplateVariable,
    )
    string_variable: StringCreativeTemplateVariable = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="SubType",
        message=StringCreativeTemplateVariable,
    )
    url_variable: UrlCreativeTemplateVariable = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="SubType",
        message=UrlCreativeTemplateVariable,
    )
    label: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )
    unique_display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    required: bool = proto.Field(
        proto.BOOL,
        number=4,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import cms_metadata_key_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CmsMetadataKey",
    },
)


class CmsMetadataKey(proto.Message):
    r"""Key associated with a piece of content from a publisher's
    CMS.

    Attributes:
        name (str):
            Identifier. The resource name of the ``CmsMetadataKey``.
            Format:
            ``networks/{network_code}/cmsMetadataKeys/{cms_metadata_key_id}``
        display_name (str):
            Required. The key of a key-value pair.
        status (google.ads.admanager_v1.types.CmsMetadataKeyStatusEnum.CmsMetadataKeyStatus):
            Output only. The status of this CMS metadata
            key.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    status: cms_metadata_key_enums.CmsMetadataKeyStatusEnum.CmsMetadataKeyStatus = (
        proto.Field(
            proto.ENUM,
            number=4,
            enum=cms_metadata_key_enums.CmsMetadataKeyStatusEnum.CmsMetadataKeyStatus,
        )
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import site_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Site",
        "DisapprovalReason",
    },
)


class Site(proto.Message):
    r"""A Site represents a domain owned or represented by a network.
    For a parent network managing other networks as part of Multiple
    Customer Management "Manage Inventory" model, it could be the
    child's domain.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``Site``. Format:
            ``networks/{network_code}/sites/{site_id}``
        url (str):
            Required. The URL of the Site.

            This field is a member of `oneof`_ ``_url``.
        child_network_code (str):
            Optional. The network code of the child if
            the Site is being managed for an MCM child
            network, or null if owned by this network.

            This field is a member of `oneof`_ ``_child_network_code``.
        approval_status (google.ads.admanager_v1.types.SiteApprovalStatusEnum.SiteApprovalStatus):
            Output only. Status of the review performed
            on the Site by Google.

            This field is a member of `oneof`_ ``_approval_status``.
        approval_status_update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The latest Site approval status
            change time.

            This field is a member of `oneof`_ ``_approval_status_update_time``.
        disapproval_reasons (MutableSequence[google.ads.admanager_v1.types.DisapprovalReason]):
            Output only. Provides reasons for
            disapproving the Site. It is null when the Site
            is not disapproved.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    url: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    child_network_code: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    approval_status: site_enums.SiteApprovalStatusEnum.SiteApprovalStatus = proto.Field(
        proto.ENUM,
        number=5,
        optional=True,
        enum=site_enums.SiteApprovalStatusEnum.SiteApprovalStatus,
    )
    approval_status_update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    disapproval_reasons: MutableSequence["DisapprovalReason"] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message="DisapprovalReason",
    )


class DisapprovalReason(proto.Message):
    r"""Represents the reason for which Google disapproved the Site.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        type_ (google.ads.admanager_v1.types.SiteDisapprovalReasonEnum.SiteDisapprovalReason):
            Output only. The type of policy violation
            found for the Site.

            This field is a member of `oneof`_ ``_type``.
        details (str):
            Output only. Additional details for the
            disapproval of the Site.

            This field is a member of `oneof`_ ``_details``.
    """

    type_: site_enums.SiteDisapprovalReasonEnum.SiteDisapprovalReason = proto.Field(
        proto.ENUM,
        number=1,
        optional=True,
        enum=site_enums.SiteDisapprovalReasonEnum.SiteDisapprovalReason,
    )
    details: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.rpc import status_pb2  # type: ignore
from google.type import interval_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import (
    ad_review_center_ad_enums,
    ad_review_center_ad_messages,
)

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "SearchAdReviewCenterAdsRequest",
        "SearchAdReviewCenterAdsResponse",
        "BatchAllowAdReviewCenterAdsRequest",
        "BatchAllowAdReviewCenterAdsResponse",
        "BatchBlockAdReviewCenterAdsRequest",
        "BatchBlockAdReviewCenterAdsResponse",
        "BatchAdReviewCenterAdsOperationMetadata",
    },
)


class SearchAdReviewCenterAdsRequest(proto.Message):
    r"""Request object for ``SearchAdReviewCenterAds`` method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of
            AdReviewCenterAds. Format:
            networks/{network_code}/webProperties/{web_property_code}

            Since a network can only have a single web property of each
            ``ExchangeSyndicationProduct``, you can use the
            ``ExchangeSyndicationProduct`` as an alias for the web
            property code:

            ``networks/{network_code}/webProperties/display``

            ``networks/{network_code}/webProperties/videoAndAudio``

            ``networks/{network_code}/webProperties/mobileApp``

            ``networks/{network_code}/webProperties/games``
        page_size (int):
            Optional. The maximum number of
            AdReviewCenterAds to return. The service may
            return fewer than this value. If unspecified, at
            most 50 AdReviewCenterAds will be returned. The
            maximum value is 1000; values greater than 1000
            will be coerced to 1000.
        page_token (str):
            Optional. The page token to fetch the next
            page of AdReviewCenterAds. This is the value
            returned from a previous Search request, or
            empty.
        status (google.ads.admanager_v1.types.AdReviewCenterAdStatusEnum.AdReviewCenterAdStatus):
            Optional. Only return ads with the given
            status.
        ad_review_center_ad_id (MutableSequence[str]):
            Optional. Only return ads with the given
            AdReviewCenterAd IDs. If provided, no other
            filter can be set (other than page size and page
            token).
        date_time_range (google.type.interval_pb2.Interval):
            Optional. If provided, only return ads that
            served within the given date range (inclusive).
            The  date range must be within the last 30 days.
            If not provided, the date range will be the last
            30 days.
        search_text (MutableSequence[str]):
            Optional. If provided, restrict the search to
            AdReviewCenterAds associated with the text (including any
            text on the ad or in the destination URL). If more than one
            value is provided, the search will combine them in a logical
            AND. For example, ['car', 'blue'] will match ads that
            contain both "car" and "blue", but not an ad that only
            contains "car".
        buyer_account_id (MutableSequence[int]):
            Optional. If provided, restrict the search to
            creatives belonging to one of the given Adx
            buyer account IDs. Only applicable to RTB
            creatives. Adx buyer account IDs can be found
            via the ProgrammaticBuyerService.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    status: ad_review_center_ad_enums.AdReviewCenterAdStatusEnum.AdReviewCenterAdStatus = proto.Field(
        proto.ENUM,
        number=4,
        enum=ad_review_center_ad_enums.AdReviewCenterAdStatusEnum.AdReviewCenterAdStatus,
    )
    ad_review_center_ad_id: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    date_time_range: interval_pb2.Interval = proto.Field(
        proto.MESSAGE,
        number=6,
        message=interval_pb2.Interval,
    )
    search_text: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    buyer_account_id: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=8,
    )


class SearchAdReviewCenterAdsResponse(proto.Message):
    r"""Response object for ``SearchAdReviewCenterAds`` method.

    Attributes:
        ad_review_center_ads (MutableSequence[google.ads.admanager_v1.types.AdReviewCenterAd]):
            The AdReviewCenterAds that match the search
            request.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    ad_review_center_ads: MutableSequence[
        ad_review_center_ad_messages.AdReviewCenterAd
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_review_center_ad_messages.AdReviewCenterAd,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class BatchAllowAdReviewCenterAdsRequest(proto.Message):
    r"""Request object for ``BatchAllowAdReviewCenterAds`` method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of
            AdReviewCenterAds. Format:
            networks/{network_code}/webProperties/{web_property_code}

            Since a network can only have a single web property of each
            ``ExchangeSyndicationProduct``, you can use the
            ``ExchangeSyndicationProduct`` as an alias for the web
            property code:

            ``networks/{network_code}/webProperties/display``

            ``networks/{network_code}/webProperties/videoAndAudio``

            ``networks/{network_code}/webProperties/mobileApp``

            ``networks/{network_code}/webProperties/games``
        names (MutableSequence[str]):
            Required. The resource names of the ``AdReviewCenterAd``\ s
            to allow. Format:
            ``networks/{network_code}/webProperties/{web_property_code}/adReviewCenterAds/{ad_review_center_ad_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class BatchAllowAdReviewCenterAdsResponse(proto.Message):
    r"""Response object for ``BatchAllowAdReviewCenterAds`` method."""


class BatchBlockAdReviewCenterAdsRequest(proto.Message):
    r"""Request object for ``BatchBlockAdReviewCenterAds`` method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of
            AdReviewCenterAds. Format:
            networks/{network_code}/webProperties/{web_property_code}

            Since a network can only have a single web property of each
            ``ExchangeSyndicationProduct``, you can use the
            ``ExchangeSyndicationProduct`` as an alias for the web
            property code:

            ``networks/{network_code}/webProperties/display``

            ``networks/{network_code}/webProperties/videoAndAudio``

            ``networks/{network_code}/webProperties/mobileApp``

            ``networks/{network_code}/webProperties/games``
        names (MutableSequence[str]):
            Required. The resource names of the ``AdReviewCenterAd``\ s
            to block. Format:
            ``networks/{network_code}/webProperties/{web_property_code}/adReviewCenterAds/{ad_review_center_ad_id}``
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class BatchBlockAdReviewCenterAdsResponse(proto.Message):
    r"""Response object for ``BatchBlockAdReviewCenterAds`` method."""


class BatchAdReviewCenterAdsOperationMetadata(proto.Message):
    r"""Metadata object for ``BatchAllowAdReviewCenterAds`` and
    ``BatchBlockAdReviewCenterAds`` methods.

    Attributes:
        failed_requests (MutableMapping[int, google.rpc.status_pb2.Status]):
            The status of each failed request, keyed by
            the index of the corresponding request in the
            batch request.
    """

    failed_requests: MutableMapping[int, status_pb2.Status] = proto.MapField(
        proto.INT32,
        proto.MESSAGE,
        number=1,
        message=status_pb2.Status,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "ContactStatusEnum",
    },
)


class ContactStatusEnum(proto.Message):
    r"""Wrapper message for
    [ContactStatus][google.ads.admanager.v1.ContactStatusEnum.ContactStatus]

    """

    class ContactStatus(proto.Enum):
        r"""Describes the contact statuses.

        Values:
            CONTACT_STATUS_UNSPECIFIED (0):
                Default value. This value is unused.
            INVITE_CANCELED (1):
                The contact was invited to see their orders,
                but the invitation was cancelled.
            INVITE_EXPIRED (2):
                The contact has been invited to see their
                orders, but the invitation has already expired.
            INVITE_PENDING (3):
                The contact has been invited to see their
                orders, but has not yet accepted the invitation.
            UNINVITED (4):
                The contact has not been invited to see their
                orders.
            USER_ACTIVE (5):
                The contact has access to login and view
                their orders.
            USER_DISABLED (6):
                The contact accepted an invitation to see
                their orders, but their access was later
                revoked.
        """
        CONTACT_STATUS_UNSPECIFIED = 0
        INVITE_CANCELED = 1
        INVITE_EXPIRED = 2
        INVITE_PENDING = 3
        UNINVITED = 4
        USER_ACTIVE = 5
        USER_DISABLED = 6


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import money_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import custom_field_value
from google.ads.admanager_v1.types import goal as gaa_goal
from google.ads.admanager_v1.types import line_item_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "LineItem",
    },
)


class LineItem(proto.Message):
    r"""A LineItem contains information about how specific ad
    creatives are intended to serve to your website or app along
    with pricing and other delivery details.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``LineItem``. Format:
            ``networks/{network_code}/lineItems/{line_item_id}``
        order (str):
            Output only. The ID of the Order to which the LineItem
            belongs. This attribute is required. Format:
            ``networks/{network_code}/orders/{order}``

            This field is a member of `oneof`_ ``_order``.
        display_name (str):
            Required. The name of the line item. This
            attribute is required and has a maximum length
            of 255 characters.

            This field is a member of `oneof`_ ``_display_name``.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Required. The date and time on which the
            LineItem is enabled to begin serving. This
            attribute is required and must be in the future.

            This field is a member of `oneof`_ ``_start_time``.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when the LineItem
            will stop serving. This attribute is read-only
            and includes auto extension days.

            This field is a member of `oneof`_ ``_end_time``.
        line_item_type (google.ads.admanager_v1.types.LineItemTypeEnum.LineItemType):
            Required. Indicates the line item type of a
            LineItem. This attribute is required. The line
            item type determines the default priority of the
            line item. More information can be found at
            https://support.google.com/admanager/answer/177279.

            This field is a member of `oneof`_ ``_line_item_type``.
        rate (google.type.money_pb2.Money):
            Required. The amount of money to spend per
            impression or click.

            This field is a member of `oneof`_ ``_rate``.
        budget (google.type.money_pb2.Money):
            Output only. The amount of money allocated to
            the LineItem. This attribute is readonly and is
            populated by Google. The currency code is
            readonly.

            This field is a member of `oneof`_ ``_budget``.
        custom_field_values (MutableSequence[google.ads.admanager_v1.types.CustomFieldValue]):
            Optional. The values of the custom fields
            associated with this line item.
        goal (google.ads.admanager_v1.types.Goal):
            Optional. The primary goal that this LineItem
            is associated with, which is used in its pacing
            and budgeting.

            This field is a member of `oneof`_ ``_goal``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    order: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    line_item_type: line_item_enums.LineItemTypeEnum.LineItemType = proto.Field(
        proto.ENUM,
        number=17,
        optional=True,
        enum=line_item_enums.LineItemTypeEnum.LineItemType,
    )
    rate: money_pb2.Money = proto.Field(
        proto.MESSAGE,
        number=20,
        optional=True,
        message=money_pb2.Money,
    )
    budget: money_pb2.Money = proto.Field(
        proto.MESSAGE,
        number=35,
        optional=True,
        message=money_pb2.Money,
    )
    custom_field_values: MutableSequence[
        custom_field_value.CustomFieldValue
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=59,
        message=custom_field_value.CustomFieldValue,
    )
    goal: gaa_goal.Goal = proto.Field(
        proto.MESSAGE,
        number=76,
        optional=True,
        message=gaa_goal.Goal,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CustomTargetingKeyStatusEnum",
        "CustomTargetingKeyTypeEnum",
        "CustomTargetingKeyReportableTypeEnum",
    },
)


class CustomTargetingKeyStatusEnum(proto.Message):
    r"""Wrapper message for
    [CustomTargetingKeyStatus][google.ads.admanager.v1.CustomTargetingKeyStatusEnum.CustomTargetingKeyStatus]

    """

    class CustomTargetingKeyStatus(proto.Enum):
        r"""Status of the custom targeting key.

        Values:
            CUSTOM_TARGETING_KEY_STATUS_UNSPECIFIED (0):
                Not specified value.
            ACTIVE (1):
                Custom targeting key is active.
            INACTIVE (2):
                Custom targeting key is inactive.
        """
        CUSTOM_TARGETING_KEY_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2


class CustomTargetingKeyTypeEnum(proto.Message):
    r"""Wrapper message for
    [CustomTargetingKeyType][google.ads.admanager.v1.CustomTargetingKeyTypeEnum.CustomTargetingKeyType]

    """

    class CustomTargetingKeyType(proto.Enum):
        r"""Type of the custom targeting key.

        Values:
            CUSTOM_TARGETING_KEY_TYPE_UNSPECIFIED (0):
                Not specified value.
            PREDEFINED (1):
                Key with a fixed set of values.
            FREEFORM (2):
                Key without a fixed set of values
        """
        CUSTOM_TARGETING_KEY_TYPE_UNSPECIFIED = 0
        PREDEFINED = 1
        FREEFORM = 2


class CustomTargetingKeyReportableTypeEnum(proto.Message):
    r"""Wrapper message for
    [CustomTargetingKeyReportableType][google.ads.admanager.v1.CustomTargetingKeyReportableTypeEnum.CustomTargetingKeyReportableType]

    """

    class CustomTargetingKeyReportableType(proto.Enum):
        r"""Reportable type of the custom targeting key.

        Values:
            CUSTOM_TARGETING_KEY_REPORTABLE_TYPE_UNSPECIFIED (0):
                Not specified value.
            OFF (1):
                Not available for reporting in the Ad Manager
                query tool.
            ON (2):
                Available for reporting in the Ad Manager
                query tool.
            CUSTOM_DIMENSION (3):
                Custom dimension available for reporting in
                the AdManager query tool.
        """
        CUSTOM_TARGETING_KEY_REPORTABLE_TYPE_UNSPECIFIED = 0
        OFF = 1
        ON = 2
        CUSTOM_DIMENSION = 3


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "PrivateMarketplaceDealStatusEnum",
    },
)


class PrivateMarketplaceDealStatusEnum(proto.Message):
    r"""Wrapper message for
    [PrivateMarketplaceDealStatus][google.ads.admanager.v1.PrivateMarketplaceDealStatusEnum.PrivateMarketplaceDealStatus].

    """

    class PrivateMarketplaceDealStatus(proto.Enum):
        r"""Describes the status of a private marketplace deal.

        Values:
            PRIVATE_MARKETPLACE_DEAL_STATUS_UNSPECIFIED (0):
                No value specified.
            PENDING (1):
                The deal is pending.
            ACTIVE (2):
                The deal is active.
            CANCELED (3):
                The deal is canceled.
            SELLER_PAUSED (4):
                The deal is paused by the seller.
            BUYER_PAUSED (5):
                The deal is paused by the buyer.
        """
        PRIVATE_MARKETPLACE_DEAL_STATUS_UNSPECIFIED = 0
        PENDING = 1
        ACTIVE = 2
        CANCELED = 3
        SELLER_PAUSED = 4
        BUYER_PAUSED = 5


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import custom_targeting_key_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CustomTargetingKey",
    },
)


class CustomTargetingKey(proto.Message):
    r"""The ``CustomTargetingKey`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``CustomTargetingKey``.
            Format:
            ``networks/{network_code}/customTargetingKeys/{custom_targeting_key_id}``
        custom_targeting_key_id (int):
            Output only. ``CustomTargetingKey`` ID.

            This field is a member of `oneof`_ ``_custom_targeting_key_id``.
        ad_tag_name (str):
            Immutable. Name of the key. Keys can contain up to 10
            characters each. You can use alphanumeric characters and
            symbols other than the following: ", ', =, !, +, #, \*, ~,
            ;, ^, (, ), <, >, [, ], the white space character.

            This field is a member of `oneof`_ ``_ad_tag_name``.
        display_name (str):
            Optional. Descriptive name for the ``CustomTargetingKey``.

            This field is a member of `oneof`_ ``_display_name``.
        type_ (google.ads.admanager_v1.types.CustomTargetingKeyTypeEnum.CustomTargetingKeyType):
            Required. Indicates whether users will select
            from predefined values or create new targeting
            values, while specifying targeting criteria for
            a line item.

            This field is a member of `oneof`_ ``_type``.
        status (google.ads.admanager_v1.types.CustomTargetingKeyStatusEnum.CustomTargetingKeyStatus):
            Output only. Status of the ``CustomTargetingKey``.

            This field is a member of `oneof`_ ``_status``.
        reportable_type (google.ads.admanager_v1.types.CustomTargetingKeyReportableTypeEnum.CustomTargetingKeyReportableType):
            Required. Reportable state of the ``CustomTargetingKey``.

            This field is a member of `oneof`_ ``_reportable_type``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    custom_targeting_key_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    ad_tag_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    type_: custom_targeting_key_enums.CustomTargetingKeyTypeEnum.CustomTargetingKeyType = proto.Field(
        proto.ENUM,
        number=5,
        optional=True,
        enum=custom_targeting_key_enums.CustomTargetingKeyTypeEnum.CustomTargetingKeyType,
    )
    status: custom_targeting_key_enums.CustomTargetingKeyStatusEnum.CustomTargetingKeyStatus = proto.Field(
        proto.ENUM,
        number=6,
        optional=True,
        enum=custom_targeting_key_enums.CustomTargetingKeyStatusEnum.CustomTargetingKeyStatus,
    )
    reportable_type: custom_targeting_key_enums.CustomTargetingKeyReportableTypeEnum.CustomTargetingKeyReportableType = proto.Field(
        proto.ENUM,
        number=7,
        optional=True,
        enum=custom_targeting_key_enums.CustomTargetingKeyReportableTypeEnum.CustomTargetingKeyReportableType,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "TimeUnitEnum",
    },
)


class TimeUnitEnum(proto.Message):
    r"""Wrapper message for TimeUnit."""

    class TimeUnit(proto.Enum):
        r"""Unit of time for the frequency cap.

        Values:
            TIME_UNIT_UNSPECIFIED (0):
                Default value. This value is unused.
            MINUTE (1):
                Minute
            HOUR (2):
                Hour
            DAY (3):
                Day
            WEEK (4):
                Week
            MONTH (5):
                Month
            LIFETIME (6):
                Lifetime
            POD (7):
                Per pod of ads in a video stream. Only valid for entities in
                a VIDEO_PLAYER environment.
            STREAM (8):
                Per video stream. Only valid for entities in a VIDEO_PLAYER
                environment.
        """
        TIME_UNIT_UNSPECIFIED = 0
        MINUTE = 1
        HOUR = 2
        DAY = 3
        WEEK = 4
        MONTH = 5
        LIFETIME = 6
        POD = 7
        STREAM = 8


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "AdUnitStatusEnum",
        "SmartSizeModeEnum",
        "TargetWindowEnum",
    },
)


class AdUnitStatusEnum(proto.Message):
    r"""Wrapper message for
    [AdUnitStatus][google.ads.admanager.v1.AdUnitStatusEnum.AdUnitStatus]

    """

    class AdUnitStatus(proto.Enum):
        r"""The status of an AdUnit.

        Values:
            AD_UNIT_STATUS_UNSPECIFIED (0):
                Default value. This value is unused.
            ACTIVE (1):
                The ad unit is active, available for
                targeting, and serving.
            INACTIVE (2):
                The ad unit will be visible in the UI, but
                ignored by serving.
            ARCHIVED (3):
                The ad unit will be hidden in the UI and
                ignored by serving.
        """
        AD_UNIT_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2
        ARCHIVED = 3


class SmartSizeModeEnum(proto.Message):
    r"""Wrapper message for
    [SmartSizeMode][google.ads.admanager.v1.SmartSizeModeEnum.SmartSizeMode].

    """

    class SmartSizeMode(proto.Enum):
        r"""The smart size mode for this ad unit. This attribute is
        optional and defaults to SmartSizeMode.NONE for fixed sizes.

        Values:
            SMART_SIZE_MODE_UNSPECIFIED (0):
                Default value. This value is unused.
            NONE (1):
                Fixed size mode (default).
            SMART_BANNER (2):
                The height is fixed for the request, the
                width is a range.
            DYNAMIC_SIZE (3):
                Height and width are ranges.
        """
        SMART_SIZE_MODE_UNSPECIFIED = 0
        NONE = 1
        SMART_BANNER = 2
        DYNAMIC_SIZE = 3


class TargetWindowEnum(proto.Message):
    r"""Wrapper message for
    [TargetWindow][google.ads.admanager.v1.TargetWindowEnum.TargetWindow].

    """

    class TargetWindow(proto.Enum):
        r"""Corresponds to an HTML link's target attribute.
        See http://www.w3.org/TR/html401/present/frames.html#adef-target

        Values:
            TARGET_WINDOW_UNSPECIFIED (0):
                Default value. This value is unused.
            TOP (1):
                Specifies that the link should open in the
                full body of the page.
            BLANK (2):
                Specifies that the link should open in a new
                window.
        """
        TARGET_WINDOW_UNSPECIFIED = 0
        TOP = 1
        BLANK = 2


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import cms_metadata_value_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CmsMetadataValue",
    },
)


class CmsMetadataValue(proto.Message):
    r"""Key value pair associated with a piece of content from a
    publisher's CMS.

    Attributes:
        name (str):
            Identifier. The resource name of the ``CmsMetadataValue``.
            Format:
            ``networks/{network_code}/cmsMetadataValues/{cms_metadata_value_id}``
        display_name (str):
            The value of this key-value pair.
        key (str):
            Required. Immutable. The resource name of the
            CmsMetadataKey. Format:
            "networks/{network_code}/cmsMetadataKey/{cms_metadata_key_id}".
        status (google.ads.admanager_v1.types.CmsMetadataValueStatusEnum.CmsMetadataValueStatus):
            Output only. The status of this CMS metadata
            value.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    key: str = proto.Field(
        proto.STRING,
        number=5,
    )
    status: cms_metadata_value_enums.CmsMetadataValueStatusEnum.CmsMetadataValueStatus = proto.Field(
        proto.ENUM,
        number=6,
        enum=cms_metadata_value_enums.CmsMetadataValueStatusEnum.CmsMetadataValueStatus,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "LineItemTypeEnum",
    },
)


class LineItemTypeEnum(proto.Message):
    r"""Wrapper message for
    [LineItemType][google.ads.admanager.v1.LineItemTypeEnum.LineItemType].

    """

    class LineItemType(proto.Enum):
        r"""Indicates the priority of a LineItem, determined by the way
        in which impressions are reserved to be served for it.

        Values:
            LINE_ITEM_TYPE_UNSPECIFIED (0):
                Not specified value.
            SPONSORSHIP (12):
                The type of LineItem for which a percentage
                of all the impressions that are being sold are
                reserved.
            STANDARD (13):
                The type of LineItem for which a fixed
                quantity of impressions or clicks are reserved.
            NETWORK (9):
                The type of LineItem most commonly used to
                fill a site's unsold inventory if not
                contractually obligated to deliver a requested
                number of impressions. Uses daily percentage of
                unsold impressions or clicks.
            BULK (4):
                The type of LineItem for which a fixed
                quantity of impressions or clicks will be
                delivered at a priority lower than the STANDARD
                type.
            PRICE_PRIORITY (11):
                The type of LineItem most commonly used to
                fill a site's unsold inventory if not
                contractually obligated to deliver a requested
                number of impressions. Uses fixed quantity
                percentage of unsold impressions or clicks.
            HOUSE (7):
                The type of LineItem typically used for ads
                that promote products and services chosen by the
                publisher.
            CLICK_TRACKING (6):
                The type of LineItem used for ads that track
                ads being served externally of Ad Manager.
            ADSENSE (2):
                Targets the LineItem to specific inventory
                available to AdSense buyers.
            AD_EXCHANGE (3):
                Targets the LineItem to specific inventory
                available to Authorized Buyers and the Open
                Auction.
            BUMPER (5):
                Represents a non-monetizable video LineItem
                that targets one or more bumper positions, which
                are short house video messages used by
                publishers to separate content from ad breaks.
            PREFERRED_DEAL (10):
                The type of LineItem for which there are no
                impressions reserved, and will serve for a
                second price bid.
            AUDIENCE_EXTENSION (14):
                The type of LineItem used for configuring
                audience extension campaigns.
        """
        LINE_ITEM_TYPE_UNSPECIFIED = 0
        SPONSORSHIP = 12
        STANDARD = 13
        NETWORK = 9
        BULK = 4
        PRICE_PRIORITY = 11
        HOUSE = 7
        CLICK_TRACKING = 6
        ADSENSE = 2
        AD_EXCHANGE = 3
        BUMPER = 5
        PREFERRED_DEAL = 10
        AUDIENCE_EXTENSION = 14


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import team_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Team",
    },
)


class Team(proto.Message):
    r"""A Team defines a grouping of users and what entities they
    have access to.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``Team``. Format:
            ``networks/{network_code}/teams/{team_id}``
        display_name (str):
            Required. The name of the Team. This value
            has a maximum length of 127 characters.

            This field is a member of `oneof`_ ``_display_name``.
        description (str):
            Optional. The description of the Team. This
            value has a maximum length of 255 characters.

            This field is a member of `oneof`_ ``_description``.
        status (google.ads.admanager_v1.types.TeamStatusEnum.TeamStatus):
            Output only. The status of the Team. This
            value determines the visibility of the team in
            the UI.

            This field is a member of `oneof`_ ``_status``.
        all_companies_access (bool):
            Optional. Whether or not users on this team
            have access to all companies. If this value is
            true, then an error will be thrown if an attempt
            is made to associate this team with a Company.

            This field is a member of `oneof`_ ``_all_companies_access``.
        all_inventory_access (bool):
            Optional. Whether or not users on this team
            have access to all inventory. If this value is
            true, then an error will be thrown if an attempt
            is made to associate this team with an AdUnit.

            This field is a member of `oneof`_ ``_all_inventory_access``.
        access_type (google.ads.admanager_v1.types.TeamAccessTypeEnum.TeamAccessType):
            Optional. The default access to orders for
            users on this team.

            This field is a member of `oneof`_ ``_access_type``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    status: team_enums.TeamStatusEnum.TeamStatus = proto.Field(
        proto.ENUM,
        number=5,
        optional=True,
        enum=team_enums.TeamStatusEnum.TeamStatus,
    )
    all_companies_access: bool = proto.Field(
        proto.BOOL,
        number=6,
        optional=True,
    )
    all_inventory_access: bool = proto.Field(
        proto.BOOL,
        number=7,
        optional=True,
    )
    access_type: team_enums.TeamAccessTypeEnum.TeamAccessType = proto.Field(
        proto.ENUM,
        number=8,
        optional=True,
        enum=team_enums.TeamAccessTypeEnum.TeamAccessType,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "DealBuyerPermissionTypeEnum",
    },
)


class DealBuyerPermissionTypeEnum(proto.Message):
    r"""Wrapper message for
    [DealBuyerPermissionType][google.ads.admanager.v1.DealBuyerPermissionTypeEnum.DealBuyerPermissionType].

    """

    class DealBuyerPermissionType(proto.Enum):
        r"""Defines how a deal would transact among all buyers under the
        same bidder.

        Values:
            DEAL_BUYER_PERMISSION_TYPE_UNSPECIFIED (0):
                No value specified.
            NEGOTIATOR_ONLY (1):
                The deal only transacts with the buyer
                specified.
            BIDDER (2):
                The deal transacts with all buyers under the
                same bidder.
        """
        DEAL_BUYER_PERMISSION_TYPE_UNSPECIFIED = 0
        NEGOTIATOR_ONLY = 1
        BIDDER = 2


__all__ = tuple(sorted(__protobuf__.manifest))
